I2sDmaChannel

Struct I2sDmaChannel 

pub struct I2sDmaChannel<'d>(/* private fields */);
Available on crate feature unstable only.
An I2S-compatible type-erased DMA channel.

A type-erased version of a peripheral singleton. Useful for creating arrays of peripherals, or avoiding generics. Peripheral singletons can be type erased by using their From implementation.

let any_peripheral = I2sDmaChannel::from(peripheral);

Implementations

Source

impl I2sDmaChannel<'_>

pub unsafe fn clone_unchecked(&self) -> Self

Unsafely clone this peripheral reference.

Safety

The caller must ensure that only one instance of this type is used at a time.

pub fn reborrow(&mut self) -> I2sDmaChannel<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method to keep working with the peripheral after dropping the driver that consumes this.

See Peripheral singleton section for more information.

pub fn downcast<P>(self) -> Result<P, Self>
where Self: TryInto<P, Error = Self>,

Attempts to downcast the pin into the underlying peripheral instance.

Example
// let peri0 = peripherals.PERI0;
// let peri1 = peripherals.PERI1;
let any_peri0 = AnyPeripheral::from(peri0);
let any_peri1 = AnyPeripheral::from(peri1);

let uart0 = any_peri0
    .downcast::<PERI0>()
    .expect("This downcast succeeds because AnyPeripheral was created from Peri0");
let uart0 = any_peri1
    .downcast::<PERI0>()
    .expect_err("This AnyPeripheral was created from Peri1, it cannot be downcast to Peri0");