pub struct SpiDmaChannel<'d>(/* private fields */);Available on crate feature
unstable only.Expand description
An SPI-compatible type-erased DMA channel.
A type-erased version of a peripheral singleton. Useful
for creating arrays of peripherals, or avoiding generics. Peripheral singletons
can be type erased by using their From implementation.
ⓘ
let any_peripheral = SpiDmaChannel::from(peripheral);Implementations
Sourceimpl SpiDmaChannel<'_>
impl SpiDmaChannel<'_>
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> SpiDmaChannel<'_>
pub fn reborrow(&mut self) -> SpiDmaChannel<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after dropping the driver that consumes this.
See Peripheral singleton section for more information.
Sourcepub fn downcast<P>(self) -> Result<P, Self>where
Self: TryInto<P, Error = Self>,
pub fn downcast<P>(self) -> Result<P, Self>where
Self: TryInto<P, Error = Self>,
Attempts to downcast the pin into the underlying peripheral instance.
Example
// let peri0 = peripherals.PERI0;
// let peri1 = peripherals.PERI1;
let any_peri0 = AnyPeripheral::from(peri0);
let any_peri1 = AnyPeripheral::from(peri1);
let uart0 = any_peri0
.downcast::<PERI0>()
.expect("This downcast succeeds because AnyPeripheral was created from Peri0");
let uart0 = any_peri1
.downcast::<PERI0>()
.expect_err("This AnyPeripheral was created from Peri1, it cannot be downcast to Peri0");Trait Implementations
Sourceimpl<'d> Debug for SpiDmaChannel<'d>
impl<'d> Debug for SpiDmaChannel<'d>
Sourceimpl<'d> DmaChannel for SpiDmaChannel<'d>
impl<'d> DmaChannel for SpiDmaChannel<'d>
Sourcetype Rx = SpiDmaRxChannel<'d>
type Rx = SpiDmaRxChannel<'d>
A description of the RX half of a DMA Channel.
Sourcetype Tx = SpiDmaTxChannel<'d>
type Tx = SpiDmaTxChannel<'d>
A description of the TX half of a DMA Channel.
Sourceimpl<'d> DmaEligiblePeripheral<SpiDmaChannel<'d>> for AnySpi<'d>
impl<'d> DmaEligiblePeripheral<SpiDmaChannel<'d>> for AnySpi<'d>
Sourcefn dma_peripheral(&self) -> DmaPeripheral
fn dma_peripheral(&self) -> DmaPeripheral
Returns the
DmaPeripheral ID for runtime compatibility checks.Sourceimpl<'d> DmaEligiblePeripheral<SpiDmaChannel<'d>> for AnySpi<'d>
impl<'d> DmaEligiblePeripheral<SpiDmaChannel<'d>> for AnySpi<'d>
Sourcefn dma_peripheral(&self) -> DmaPeripheral
fn dma_peripheral(&self) -> DmaPeripheral
Returns the
DmaPeripheral ID for runtime compatibility checks.Sourceimpl<'d> DmaEligiblePeripheral<SpiDmaChannel<'d>> for SPI2<'d>
impl<'d> DmaEligiblePeripheral<SpiDmaChannel<'d>> for SPI2<'d>
Sourcefn dma_peripheral(&self) -> DmaPeripheral
fn dma_peripheral(&self) -> DmaPeripheral
Returns the
DmaPeripheral ID for runtime compatibility checks.Sourceimpl<'d> DmaEligiblePeripheral<SpiDmaChannel<'d>> for SPI3<'d>
impl<'d> DmaEligiblePeripheral<SpiDmaChannel<'d>> for SPI3<'d>
Sourcefn dma_peripheral(&self) -> DmaPeripheral
fn dma_peripheral(&self) -> DmaPeripheral
Returns the
DmaPeripheral ID for runtime compatibility checks.Sourceimpl<'d> From<DMA_SPI2<'d>> for SpiDmaChannel<'d>
impl<'d> From<DMA_SPI2<'d>> for SpiDmaChannel<'d>
Sourceimpl<'d> From<DMA_SPI3<'d>> for SpiDmaChannel<'d>
impl<'d> From<DMA_SPI3<'d>> for SpiDmaChannel<'d>
Sourceimpl<'d> From<SpiDmaChannel<'d>> for SpiDmaRxChannel<'d>
impl<'d> From<SpiDmaChannel<'d>> for SpiDmaRxChannel<'d>
Sourcefn from(this: SpiDmaChannel<'d>) -> SpiDmaRxChannel<'d>
fn from(this: SpiDmaChannel<'d>) -> SpiDmaRxChannel<'d>
Converts to this type from the input type.
Sourceimpl<'d> From<SpiDmaChannel<'d>> for SpiDmaTxChannel<'d>
impl<'d> From<SpiDmaChannel<'d>> for SpiDmaTxChannel<'d>
Sourcefn from(this: SpiDmaChannel<'d>) -> SpiDmaTxChannel<'d>
fn from(this: SpiDmaChannel<'d>) -> SpiDmaTxChannel<'d>
Converts to this type from the input type.
Sourceimpl<'d> TryFrom<SpiDmaChannel<'d>> for DMA_SPI2<'d>
impl<'d> TryFrom<SpiDmaChannel<'d>> for DMA_SPI2<'d>
Sourcetype Error = SpiDmaChannel<'d>
type Error = SpiDmaChannel<'d>
The type returned in the event of a conversion error.
Sourcefn try_from(any: SpiDmaChannel<'d>) -> Result<Self, SpiDmaChannel<'d>>
fn try_from(any: SpiDmaChannel<'d>) -> Result<Self, SpiDmaChannel<'d>>
Performs the conversion.
Sourceimpl<'d> TryFrom<SpiDmaChannel<'d>> for DMA_SPI3<'d>
impl<'d> TryFrom<SpiDmaChannel<'d>> for DMA_SPI3<'d>
Sourcetype Error = SpiDmaChannel<'d>
type Error = SpiDmaChannel<'d>
The type returned in the event of a conversion error.
Sourcefn try_from(any: SpiDmaChannel<'d>) -> Result<Self, SpiDmaChannel<'d>>
fn try_from(any: SpiDmaChannel<'d>) -> Result<Self, SpiDmaChannel<'d>>
Performs the conversion.